@@ -1,14 +1,14 @@
 package Complete::Unix;
 
-our $DATE = '2015-09-09'; # DATE
-our $VERSION = '0.05'; # VERSION
+our $DATE = '2015-11-29'; # DATE
+our $VERSION = '0.06'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 #use Log::Any '$log';
 
-use Complete::Setting;
+use Complete::Common qw(:all);
 
 require Exporter;
 our @ISA = qw(Exporter);
@@ -24,11 +24,6 @@ our @EXPORT_OK = qw(
 
 our %SPEC;
 
-our %common_args = (
-    word    => { schema=>[str=>{default=>''}], pos=>0, req=>1 },
-    ci      => { schema=>['bool'] },
-);
-
 $SPEC{':package'} = {
     v => 1.1,
     summary => 'Unix-related completion routines',
@@ -38,7 +33,7 @@ $SPEC{complete_uid} = {
     v => 1.1,
     summary => 'Complete from list of Unix UID\'s',
     args => {
-        %common_args,
+        %arg_word,
         etc_dir => { schema=>['str*'] },
     },
     result_naked => 1,
@@ -52,21 +47,20 @@ sub complete_uid {
 
     my %args  = @_;
     my $word  = $args{word} // "";
-    my $ci    = $args{ci} // $Complete::Setting::OPT_CI;
 
     my $res = Unix::Passwd::File::list_users(
         etc_dir=>$args{etc_dir}, detail=>1);
     return undef unless $res->[0] == 200;
     Complete::Util::complete_array_elem(
         array=>[map {$_->{uid}} @{ $res->[2] }],
-                word=>$word, ci=>$ci);
+        word=>$word);
 }
 
 $SPEC{complete_user} = {
     v => 1.1,
     summary => 'Complete from list of Unix users',
     args => {
-        %common_args,
+        %arg_word,
         etc_dir => { schema=>['str*'] },
     },
     result_naked => 1,
@@ -80,21 +74,20 @@ sub complete_user {
 
     my %args  = @_;
     my $word  = $args{word} // "";
-    my $ci    = $args{ci} // $Complete::Setting::OPT_CI;
 
     my $res = Unix::Passwd::File::list_users(
         etc_dir=>$args{etc_dir}, detail=>1);
     return undef unless $res->[0] == 200;
     Complete::Util::complete_array_elem(
         array=>[map {$_->{user}} @{ $res->[2] }],
-                word=>$word, ci=>$ci);
+        word=>$word);
 }
 
 $SPEC{complete_gid} = {
     v => 1.1,
     summary => 'Complete from list of Unix GID\'s',
     args => {
-        %common_args,
+        %arg_word,
         etc_dir => { schema=>['str*'] },
     },
     result_naked => 1,
@@ -108,21 +101,20 @@ sub complete_gid {
 
     my %args  = @_;
     my $word  = $args{word} // "";
-    my $ci    = $args{ci} // $Complete::Setting::OPT_CI;
 
     my $res = Unix::Passwd::File::list_groups(
         etc_dir=>$args{etc_dir}, detail=>1);
     return undef unless $res->[0] == 200;
     Complete::Util::complete_array_elem(
         array=>[map {$_->{gid}} @{ $res->[2] }],
-                word=>$word, ci=>$ci);
+        word=>$word);
 }
 
 $SPEC{complete_group} = {
     v => 1.1,
     summary => 'Complete from list of Unix groups',
     args => {
-        %common_args,
+        %arg_word,
         etc_dir => { schema=>['str*'] },
     },
     result_naked => 1,
@@ -136,21 +128,20 @@ sub complete_group {
 
     my %args  = @_;
     my $word  = $args{word} // "";
-    my $ci    = $args{ci} // $Complete::Setting::OPT_CI;
 
     my $res = Unix::Passwd::File::list_groups(
         etc_dir=>$args{etc_dir}, detail=>1);
     return undef unless $res->[0] == 200;
     Complete::Util::complete_array_elem(
         array=>[map {$_->{group}} @{ $res->[2] }],
-                word=>$word, ci=>$ci);
+        word=>$word);
 }
 
 $SPEC{complete_pid} = {
     v => 1.1,
     summary => 'Complete from list of running PIDs',
     args => {
-        %common_args,
+        %arg_word,
     },
     result_naked => 1,
     result => {
@@ -163,18 +154,17 @@ sub complete_pid {
 
     my %args  = @_;
     my $word  = $args{word} // "";
-    my $ci    = $args{ci} // $Complete::Setting::OPT_CI;
 
     Complete::Util::complete_array_elem(
         array=>Proc::Find::find_proc(),
-                word=>$word, ci=>$ci);
+        word=>$word);
 }
 
 $SPEC{complete_proc_name} = {
     v => 1.1,
     summary => 'Complete from list of process names',
     args => {
-        %common_args,
+        %arg_word,
     },
     result_naked => 1,
     result => {
@@ -188,14 +178,13 @@ sub complete_proc_name {
 
     my %args  = @_;
     my $word  = $args{word} // "";
-    my $ci    = $args{ci} // $Complete::Setting::OPT_CI;
 
     Complete::Util::complete_array_elem(
         array=>[List::MoreUtils::uniq(
             grep {length}
                 map { $_->{name} }
                     @{ Proc::Find::find_proc(detail=>1) })],
-        word=>$word, ci=>$ci);
+        word=>$word);
 }
 
 1;
@@ -213,7 +202,7 @@ Complete::Unix - Unix-related completion routines
 
 =head1 VERSION
 
-This document describes version 0.05 of Complete::Unix (from Perl distribution Complete-Unix), released on 2015-09-09.
+This document describes version 0.06 of Complete::Unix (from Perl distribution Complete-Unix), released on 2015-11-29.
 
 =head1 DESCRIPTION
 
@@ -224,16 +213,18 @@ This document describes version 0.05 of Complete::Unix (from Perl distribution C
 
 Complete from list of Unix GID's.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<ci> => I<bool>
-
 =item * B<etc_dir> => I<str>
 
 =item * B<word>* => I<str> (default: "")
 
+Word to complete.
+
 =back
 
 Return value:  (array)
@@ -243,16 +234,18 @@ Return value:  (array)
 
 Complete from list of Unix groups.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<ci> => I<bool>
-
 =item * B<etc_dir> => I<str>
 
 =item * B<word>* => I<str> (default: "")
 
+Word to complete.
+
 =back
 
 Return value:  (array)
@@ -262,14 +255,16 @@ Return value:  (array)
 
 Complete from list of running PIDs.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<ci> => I<bool>
-
 =item * B<word>* => I<str> (default: "")
 
+Word to complete.
+
 =back
 
 Return value:  (array)
@@ -279,14 +274,16 @@ Return value:  (array)
 
 Complete from list of process names.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<ci> => I<bool>
-
 =item * B<word>* => I<str> (default: "")
 
+Word to complete.
+
 =back
 
 Return value:  (array)
@@ -296,16 +293,18 @@ Return value:  (array)
 
 Complete from list of Unix UID's.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<ci> => I<bool>
-
 =item * B<etc_dir> => I<str>
 
 =item * B<word>* => I<str> (default: "")
 
+Word to complete.
+
 =back
 
 Return value:  (array)
@@ -315,16 +314,18 @@ Return value:  (array)
 
 Complete from list of Unix users.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<ci> => I<bool>
-
 =item * B<etc_dir> => I<str>
 
 =item * B<word>* => I<str> (default: "")
 
+Word to complete.
+
 =back
 
 Return value:  (array)
@@ -339,7 +340,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Complete-U
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Complete-Unix>.
+Source repository is at L<https://github.com/sharyanto/perl-Complete-Unix>.
 
 =head1 BUGS
 
